@@ -1,13 +1,13 @@
 ;;; setup.el --- Helpful Configuration Macro    -*- lexical-binding: t -*-
 
-;; Copyright (C) 2021, 2022, 2023, 2024  Free Software Foundation, Inc.
+;; Copyright (C) 2021, 2022, 2023, 2024, 2025  Free Software Foundation, Inc.
 
 ;; Author: Philip Kaludercic <philipk@posteo.net>
-;; Maintainer: Philip Kaludercic <~pkal/public-inbox@lists.sr.ht>
-;; Version: 1.4.0
+;; Maintainer: Philip Kaludercic <philipk@posteo.net>
+;; Version: 1.5.0
 ;; Package-Requires: ((emacs "26.1"))
 ;; Keywords: lisp, local
-;; URL: https://git.sr.ht/~pkal/setup
+;; URL: https://codeberg.org/pkal/setup.el
 
 ;; This package is Free Software: you can redistribute it and/or modify
 ;; it under the terms of the GNU General Public License as published by
@@ -37,28 +37,10 @@
 
 ;;; News:
 
-;;;; Version 1.4.0 (13Apr24)
+;;;; Version 1.6.0 (???)
 
-;; - New :bind-to macro, that takes a key chord and binds the
-;;   context-relevant function.  E.g.
-;;
-;;   (setup (:package do-at-point)
-;;     (:bind-to "C-'"))
-;;
-;; - New :autoload-this creates an auto-load cookie for the
-;;   context-relevant function by connecting it to the
-;;   context-relevant feature.
-;;
-;; - Avoid calling `package-refresh-contents' in :package if it is not
-;;   necessary.  The check here was broken, as Ralf Schmitt noticed.
-;;
-;; - Earl Hyatt improved the :repeatable keyword to support a prefix
-;;   of non-repeating arguments.
-;;
-;; - Passing a map to :bind-into has been deprecated, since there is
-;;   no reliable way to deduce the feature that holds the map.  I
-;;   apologise for the inconvenience.  The functionality will remain
-;;   for a while, but I would advise rewriting affected configuration.
+;; - Deprecate `:global', `:option' and `:file-match'.  Please replace
+;;   these, as they are marked for removal at some point.
 
 ;;; Code:
 
@@ -593,6 +575,9 @@ The first FEATURE can be used to deduce the feature context."
 
 (setup-define :global
   (lambda (key command)
+    ;; This command doesn't use or set any context, and thus has no
+    ;; need to be a `setup' macro.
+    (warn "The `:global' macro for setup has been deprecated, please use `keymap-global-set'.")
     `(global-set-key ,key ,command))
   :documentation "Globally bind KEY to COMMAND."
   :debug '(form sexp)
@@ -671,6 +656,10 @@ The arguments REST are handled as by `:bind'."
 (setup-define :option
   (setup-make-setter
    (lambda (name)
+     ;; This command doesn't use or set any context, and thus has no
+     ;; need to be a `setup' macro.  Features like `append'
+     ;; et. al. are in my opinion too hacky to legitimise the macro.
+     (warn "The `:option' macro for setup has been deprecated, please use `setopt'.")
      `(funcall (or (get ',name 'custom-get)
                    #'symbol-value)
                ',name))
@@ -793,11 +782,23 @@ The first FEATURE can be used to deduce the feature context."
 
 (setup-define :file-match
   (lambda (pat)
+    ;; While on the one hand this kind of a feature is not that
+    ;; useful, as most packages modify `auto-mode-alist' on their own,
+    ;; as we are dealing with file names it is more convenient to use
+    ;; globing syntax instead of regexps.
+    (warn "The `:file-match' macro for setup has been deprecated, please use `:match-file' instead.")
     `(add-to-list 'auto-mode-alist (cons ,pat ',(setup-get 'mode))))
   :documentation "Associate the current mode with files that match PAT."
   :debug '(form)
   :repeatable t)
 
+(setup-define :match-file
+  (lambda (pat)
+    `(add-to-list 'auto-mode-alist (cons ,(wildcard-to-regexp pat) ',(setup-get 'mode))))
+  :documentation "Associate the current mode with files that match PAT."
+  :debug '(form)
+  :repeatable t)
+
 (setup-define :when-loaded
   (lambda (&rest body)
     (macroexp-progn body))
